@@ -23,27 +23,32 @@ IDENTITY_API_VERSION=3
 
 SWIFT_DATA_DIR=/opt/stack/data/swift
 
-usage() {
+function usage {
     echo "Usage: s2aio.sh install"
     echo "       s2aio.sh start"
     echo "       s2aio.sh stop"
     exit 1
 }
 
-_prepare_devstack_env() {
+function _prepare_devstack_env {
     # Checkout devstack
     if [ ! -e $DEVSTACK_DIR ]; then
         git clone git://github.com/openstack-dev/devstack.git $DEVSTACK_DIR
-        cp devstack/localrc.sample $DEVSTACK_DIR/localrc
+        if [ ${USE_PYTHON3} == "False" ]; then
+          cp devstack/localrc.py2.sample $DEVSTACK_DIR/localrc
+        else
+          cp devstack/localrc.sample $DEVSTACK_DIR/localrc
+        fi
     fi
 
+    source $DEVSTACK_DIR/stackrc
     source $DEVSTACK_DIR/functions
     source $DEVSTACK_DIR/functions-common
     source $DEVSTACK_DIR/lib/swift
     source devstack/plugin.sh
 }
 
-start_s2aio() {
+function start_s2aio {
     set -e
     swift-init --run-dir ${SWIFT_DATA_DIR}/run/ all start
     /usr/local/bin/uwsgi /etc/keystone/keystone-uwsgi-public.ini &> /dev/null &
@@ -51,19 +56,19 @@ start_s2aio() {
     exit 0
 }
 
-_stop_s2aio() {
+function _stop_s2aio {
     set +e
     swift-init --run-dir ${SWIFT_DATA_DIR}/run/ all stop
     sh -c 'ps aux | pgrep uwsgi | xargs kill -9'
     set -e
 }
 
-stop_s2aio() {
+function stop_s2aio {
     _stop_s2aio
     exit 0
 }
 
-install_swift_using_devstack() {
+function install_swift_using_devstack {
     cd $DEVSTACK_DIR
     ./stack.sh
     stop_swift
@@ -76,7 +81,7 @@ install_swift_using_devstack() {
     fi
 }
 
-install_s2aio() {
+function install_s2aio {
     _prepare_devstack_env
 
     install_swift_using_devstack
@@ -88,7 +93,7 @@ install_s2aio() {
     echo "export OS_AUTH_URL=$KEYSTONE_PUBLIC_URL" >> ~/.bashrc
 }
 
-uninstall_swift_using_devstack() {
+function uninstall_swift_using_devstack {
     _stop_s2aio
     cd $DEVSTACK_DIR
     ./unstack.sh
@@ -98,8 +103,7 @@ uninstall_swift_using_devstack() {
     sudo sed -i.bak '/swift.img/d'  /etc/fstab
 }
 
-
-uninstall_s2aio() {
+function uninstall_s2aio {
     _prepare_devstack_env
 
     echo "Removing all storlets run time data"
@@ -126,6 +130,7 @@ case $COMMAND in
   "stop" )
     stop_s2aio
     ;;
+
   * )
     usage
 esac
